# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_stopspeechrecognise.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_stopspeechrecognise.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n!codemao_stopspeechrecognise.proto\"\x1c\n\x1aStopSpeechRecogniseRequest\"D\n\x1bStopSpeechRecogniseResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_STOPSPEECHRECOGNISEREQUEST = _descriptor.Descriptor(
    name='StopSpeechRecogniseRequest',
    full_name='StopSpeechRecogniseRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=37,
    serialized_end=65,
)

_STOPSPEECHRECOGNISERESPONSE = _descriptor.Descriptor(
    name='StopSpeechRecogniseResponse',
    full_name='StopSpeechRecogniseResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='StopSpeechRecogniseResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='StopSpeechRecogniseResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=67,
    serialized_end=135,
)

DESCRIPTOR.message_types_by_name['StopSpeechRecogniseRequest'] = _STOPSPEECHRECOGNISEREQUEST
DESCRIPTOR.message_types_by_name['StopSpeechRecogniseResponse'] = _STOPSPEECHRECOGNISERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopSpeechRecogniseRequest = _reflection.GeneratedProtocolMessageType('StopSpeechRecogniseRequest', (_message.Message,),
                                                                      {
                                                                          'DESCRIPTOR': _STOPSPEECHRECOGNISEREQUEST,
                                                                          '__module__': 'codemao_stopspeechrecognise_pb2'
                                                                          # @@protoc_insertion_point(class_scope:StopSpeechRecogniseRequest)
                                                                      })
_sym_db.RegisterMessage(StopSpeechRecogniseRequest)

StopSpeechRecogniseResponse = _reflection.GeneratedProtocolMessageType('StopSpeechRecogniseResponse',
                                                                       (_message.Message,), {
                                                                           'DESCRIPTOR': _STOPSPEECHRECOGNISERESPONSE,
                                                                           '__module__': 'codemao_stopspeechrecognise_pb2'
                                                                           # @@protoc_insertion_point(class_scope:StopSpeechRecogniseResponse)
                                                                       })
_sym_db.RegisterMessage(StopSpeechRecogniseResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
