# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_searchfaces.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_searchfaces.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x19\x63odemao_searchfaces.proto\"&\n\x12SearchFacesRequest\x12\x10\n\x08isSearch\x18\x01 \x01(\x08\"<\n\x13SearchFacesResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_SEARCHFACESREQUEST = _descriptor.Descriptor(
    name='SearchFacesRequest',
    full_name='SearchFacesRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSearch', full_name='SearchFacesRequest.isSearch', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=29,
    serialized_end=67,
)

_SEARCHFACESRESPONSE = _descriptor.Descriptor(
    name='SearchFacesResponse',
    full_name='SearchFacesResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='SearchFacesResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='SearchFacesResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=69,
    serialized_end=129,
)

DESCRIPTOR.message_types_by_name['SearchFacesRequest'] = _SEARCHFACESREQUEST
DESCRIPTOR.message_types_by_name['SearchFacesResponse'] = _SEARCHFACESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchFacesRequest = _reflection.GeneratedProtocolMessageType('SearchFacesRequest', (_message.Message,), {
    'DESCRIPTOR': _SEARCHFACESREQUEST,
    '__module__': 'codemao_searchfaces_pb2'
    # @@protoc_insertion_point(class_scope:SearchFacesRequest)
})
_sym_db.RegisterMessage(SearchFacesRequest)

SearchFacesResponse = _reflection.GeneratedProtocolMessageType('SearchFacesResponse', (_message.Message,), {
    'DESCRIPTOR': _SEARCHFACESRESPONSE,
    '__module__': 'codemao_searchfaces_pb2'
    # @@protoc_insertion_point(class_scope:SearchFacesResponse)
})
_sym_db.RegisterMessage(SearchFacesResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
